@@ -1,5 +1,6 @@
 import sys
 import optparse
+import re
 from optparse import Option, BadOptionError
 
 from texttable import Texttable
@@ -11,6 +12,7 @@ from rider.cli.utils import get_prog, get_userinput_boolean, get_userinput_str,
 from rider.log import Logger
 from rider.environment import Environment, ENV_CLASS_MAPPING
 from rider.image import Image
+from rider.pkg.fig.cli.docker_client import docker_client
 
 
 class Command(object):
@@ -290,13 +292,59 @@ class ShowCommand(Command):
 
         sub_commands[sub_command]().run(args_else)
 
+class WRiderCommand(Command):
+    name = "wrider"
+    usage = """%prog """
+    summary = "build wrider image with splunk package"
+
+    def __init__(self):
+        super(WRiderCommand, self).__init__()
+
+    def run(self, args):
+        client = docker_client()
+        cert_path = os.environ.get('DOCKER_CERT_PATH', '')
+        docker_host = "tcp://boot2docker:2376"
+        docker_cert_path = "/code/boot2docker-vm"
+        image_name = "10.66.128.203:49153/coreqa/wrider"
+        environment = ['DOCKER_TLS_VERIFY="1"',
+                       'DOCKER_CERT_PATH='+docker_cert_path,
+                       'DOCKER_HOST='+docker_host]
+
+        container_id = client.create_container(
+            image=image_name, environment=environment)
+
+        client.start(container=container_id, publish_all_ports=True,
+                     binds={cert_path: {'bind': docker_cert_path, 'ro': False}})
+        h_port = client.port(container_id, 5000)
+        docker_host_ip = self.get_docker_host_ip()
+        msg = '''
+        \n
+        You need to do below two steps to use your Wrider container ready:
+        1. sudo echo "{i}   boot2docker" >> /etc/hosts
+        2. Open your browser and access http://boot2docker:{p}
+        \n
+        '''.format(i=docker_host_ip, p=h_port[0].get('HostPort'))
+        sys.stdout.write(msg)
+
+    def get_docker_host_ip(self):
+        '''
+        Read DOCKER_HOST environment variable and get the IP address of docker host.
+        :return: Docker host IP address
+        '''
+        hostname = '192.168.59.103'
+        docker_host = os.environ.get('DOCKER_HOST', '')
+        if docker_host:
+            match = re.search("tcp://(.*):[0-9]+", docker_host)
+            hostname = match.group(1)
+        return hostname
 
 COMMANDS = {
     ShowCommand.name: ShowCommand,
     BuildCommand.name: BuildCommand,
     CleanCommand.name: CleanCommand,
     ScaleCommand.name: ScaleCommand,
-    BootStrapCommand.name: BootStrapCommand
+    BootStrapCommand.name: BootStrapCommand,
+    WRiderCommand.name: WRiderCommand
 }
 
 
