@@ -6,15 +6,9 @@ from pkg.fig.cli.docker_client import docker_client
 from service import Service
 
 CONTAINER_NAME_REGEX = '\s+\_\d+\_\s+\_\d+'
-DEFAULT_IMAGE = '10.66.128.203:49153/coreqa/splunk:fig'
+DEFAULT_IMAGE = '10.66.128.203:49153/coreqa/rider_splunk:49888'
 
 
-# import os
-# os.environ["FIG_FILE"] = "/Users/weiwang/work/github/rider/rider/pkg/fig.yml"
-# os.environ["DOCKER_HOST"] = 'tcp://192.168.59.103:2376'
-# os.environ["DOCKER_TLS_VERIFY"] = '1'
-# os.environ["DOCKER_CERT_PATH"] = '/Users/weiwang/.boot2docker/certs/boot2docker-vm'
-
 class Environment(object):
     """
     Represents a rider environment of splunk instances
@@ -44,6 +38,7 @@ class Environment(object):
         """
         return [Service(service.name, service, self) for service in self._project.get_services()]
 
+
     def get_scaleable_services_list(self):
         """
         Return all scale-able services as a list of current environment
@@ -182,8 +177,10 @@ class Environment(object):
         """
 
         self._project.up()
-        pass
 
+        # check the ssh
+        for service in self.service_list:
+            service.ssh_check()
 
     def bootstrap(self):
         """
@@ -197,18 +194,21 @@ class Environment(object):
 
         """
 
-        if self.env_type == "cluster":
-            self.up()
-            self.indexer.scale(3)
+        # if self.env_type == "cluster":
+        # self.up()
+        # self.indexer.scale(3)
+        #
+        # elif self.env_type == "multisite":
+        #     self.up()
+        #     self.site1indexer.scale(3)
+        #     self.site2indexer.scale(3)
+        #     self.site3indexer.scale(3)
+        #
+        # elif self.env_type == "dst":
+        #     self.up()
+        #     self.dsp.scale(3)
 
-        elif self.env_type == "multisite":
-            self.up()
-            self.site1indexer.scale(3)
-            self.site2indexer.scale(3)
-            self.site3indexer.scale(3)
-
-
-        pass
+        self.up()
 
 
     def _get_service_dict(self, image_name):
@@ -226,6 +226,10 @@ class ClusterEnvironment(Environment):
     def __init__(self, env_name, image_name):
         super(ClusterEnvironment, self).__init__(env_name, image_name)
 
+    def bootstrap(self):
+        super(ClusterEnvironment, self).bootstrap()
+        self.indexer.scale(3)
+
 
 class DistributedEnvironment(Environment):
     env_type = "dst"
@@ -233,25 +237,32 @@ class DistributedEnvironment(Environment):
     def __init__(self, env_name, image_name):
         super(DistributedEnvironment, self).__init__(env_name, image_name)
 
+    def bootstrap(self):
+        super(DistributedEnvironment, self).bootstrap()
+        self.dsp.scale(3)
+
 
 class MultisiteClusterEnvironment(Environment):
     env_type = "multisite"
 
-    def __init__(self,env_name,image_name):
-        super(MultisiteClusterEnvironment,self).__init__(env_name,image_name)
+    def __init__(self, env_name, image_name):
+        super(MultisiteClusterEnvironment, self).__init__(env_name, image_name)
+        self.site1indexer.scale(3)
+        self.site2indexer.scale(3)
+        self.site3indexer.scale(3)
 
 # class ShcEnvironment(Environment):
 # env_type = "shc"
 #
 # def __init__(self, env_name):
-#         super(ShcEnvironment, self).__init__(env_name)
+# super(ShcEnvironment, self).__init__(env_name)
 
 
 # CONSTANTS VARIABLES
 ENV_CLASS_MAPPING = {
     ClusterEnvironment.env_type: ClusterEnvironment,
-    MultisiteClusterEnvironment.env_type: MultisiteClusterEnvironment
-    # DistributedEnvironment.env_type: DistributedEnvironment,
+    MultisiteClusterEnvironment.env_type: MultisiteClusterEnvironment,
+    DistributedEnvironment.env_type: DistributedEnvironment,
     # ShcEnvironment.env_type: ShcEnvironment
 
 }
@@ -266,13 +277,17 @@ ENV_DICT_MAPPING = {
          'links': ['master'], u'name': 'indexer'}],
 
     MultisiteClusterEnvironment.env_type: [
-        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'siteindexer site1', 'ports': ['8000', '8089', '22'],
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'siteindexer site1',
+         'ports': ['8000', '8089', '22'],
          'links': ['multimaster'], u'name': 'site1indexer'},
-        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'siteindexer site2', 'ports': ['8000', '8089', '22'],
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'siteindexer site2',
+         'ports': ['8000', '8089', '22'],
          'links': ['multimaster'], u'name': 'site2indexer'},
-        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'siteindexer site3', 'ports': ['8000', '8089', '22'],
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'siteindexer site3',
+         'ports': ['8000', '8089', '22'],
          'links': ['multimaster'], u'name': 'site3indexer'},
-        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'multimaster site1,site2,site3 origin:2,total:4 origin:1,total:3', 'ports': ['8000', '8089', '22'],
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig',
+         'command': 'multimaster site1,site2,site3 origin:2,total:4 origin:1,total:3', 'ports': ['8000', '8089', '22'],
          u'name': 'multimaster'},
         {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sitesh site1', 'ports': ['8000', '8089', '22'],
          'links': ['multimaster'], u'name': 'site1sh'},
@@ -280,40 +295,20 @@ ENV_DICT_MAPPING = {
          'links': ['multimaster'], u'name': 'site2sh'},
         {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sitesh site3', 'ports': ['8000', '8089', '22'],
          'links': ['multimaster'], u'name': 'site3sh'}
-        ],
+    ],
 
 
-    # DistributedEnvironment.env_type: [
-    #     {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'dsh', 'ports': ['8000', '8089', '22'],
-    #      'links': ['dsp'], u'name': 'dsh'},
-    #     {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'dsp', 'ports': ['8000', '8089', '22'],
-    #      u'name': 'dsp'}],
+    DistributedEnvironment.env_type: [
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'dsh', 'ports': ['8000', '8089', '22'],
+         'links': ['dsp'], u'name': 'dsh'},
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'dsp', 'ports': ['8000', '8089', '22'],
+         u'name': 'dsp'}],
     # ShcEnvironment.env_type: [
     # {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'],
-    #      'links': ['master'], u'name': 'sh'},
+    # 'links': ['master'], u'name': 'sh'},
     #     {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'],
     #      u'name': 'master'},
     #     {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'],
     #      'links': ['master'], u'name': 'indexer'}]
 }
 
-# if __name__ == "__main__":
-
-    # testenv = Environment.get_environment_by_name('jacktestapi2')
-    # testenv = Environment.get_environments()
-    # print testenv[0].indexer.machines
-    # myEnv = Environment.create_environment("multisite", "jacktest")
-    #
-    # myEnv.bootstrap()
-    # myEnv.clean()
-    # myEnv.get_service_names()
-    #
-    # myEnv.up()
-    # myEnv.indexer.scale(2)
-    #
-    # print myEnv.indexer.machines[0].name
-    # Environment.get_environments()
-    # env = Environment.get_environment_by_name('dsttest_dst')
-    # print env.service_list
-    # env.clean()
-
